#!/bin/bash

# do we have the "xdelta" program on this system?
XDELTA=`type -p xdelta`
if [ ${XDELTA:-no} = "no" ]; then
	echo "No program 'xdelta' on this system."
	echo "Install package xdelta, which is in series 'ap' on"
	echo "your SuSE Linux 6.2/6.3 CD. See the website where you found"
	echo "this patch here for instructions for 6.4 - you will need the"
	echo "old xdelta package from SuSE Linux 6.3 (the website has a"
	echo "link where you can get it)."
	echo "xdelta is needed for the binary patch in this packet."
	exit 1
fi

# try to find the Oracle 8.1.5 STD installation files
if [ ! -f ../runInstaller -a ! -d ../stage/ ]; then
	echo "The directory with these patch must be in your Oracle installation"
	echo "directory, where the Oracle source files are."
	echo "It must be in the same directory as, for example, the Oracle installation"
	echo "directories stage/, install/ and Translations/, and the executable"
	echo "runInstaller. Move the entire directory Oracle8i-STD-patch/ into"
	echo "that directory!"
	exit 1
fi

# is this really the standard edition we're trying to patch?
if [ -f ../stage/Components/oracle/options/partitioning/8.1.5.0.0/1/DataFiles/lib.0.1.jar ]; then
        echo "This is not Oracle 8i Standard Edition, this is the Enterprise"
	echo "Edition!"
        echo "You got the wrong patch. Go back to http//www.suse.de/en/support/oracle/"
        echo "and get the correct one for the Enterprise Edition."
        exit 1
fi

# bug in the SuSE Linux 6.2 dependencies for xdelta may cause missing "glib" 
GLIB="no"
for i in /usr/lib/libglib-1.2.so*; do
	if [ -f $i ]; then
		GLIB="yes"
	fi
done
if [ ${GLIB:-no} = "no" ]; then
	echo "You don't have package <glib> installed, needed by xdelta."
	echo "Please install it."
	echo "(I looked for a file /usr/lib/libglib-1.2.so*)"
	exit 1;
fi

# are make/gcc/patch installed, programs the Oracle installation relies on
if [ ! -x /usr/bin/make ]; then
	echo "You don't have the program 'make' installed. Please"
	echo "install it, the Oracle installation needs it!"
	exit 1;
fi
if [ ! -x /usr/bin/gcc ]; then
	echo "You don't have the program 'gcc' installed. Please"
	echo "install it, the Oracle installation needs it!"
	exit 1;
fi
if [ ! -x /usr/bin/patch ]; then
	echo "You don't have the program 'patch' installed. Please"
	echo "install it, the Oracle installation needs it!"
	exit 1;
fi


# are we in the directory with the patch?
if [ -x ${XDELTA:-no} -a -f ./Oracle-8.1.5-STD.dif -a -f 10.delta ]; then
	clear;
	echo
	echo "Patching Oracle 8.1.5 Standard Edition"
	echo
else
	echo "You must be in the directory where the patchfiles are"
	echo "before you start this script!"
	exit 1
fi


# change to Oracle installation directory
cd ..

# just in case...
chmod -R u+w .

echo "Applying text patch..."
rm -f install/nnfgt.c
patch -p1 < ./Oracle8i-STD-patch/Oracle-8.1.5-STD.dif

echo
echo "Applying binary patches to the .jar archives..."
$XDELTA patch -V ./Oracle8i-STD-patch/1.delta  ./stage/Components/oracle/cartridges/context/8.1.5.0.0/1/DataFiles/lib.0.0.jar    ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/cartridges/context/8.1.5.0.0/1/DataFiles/lib.0.0.jar
$XDELTA patch -V ./Oracle8i-STD-patch/2.delta  ./stage/Components/oracle/emprod/oemagent/cmp/8.1.5.0.0/1/DataFiles/lib.0.0.jar   ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/emprod/oemagent/cmp/8.1.5.0.0/1/DataFiles/lib.0.0.jar
$XDELTA patch -V ./Oracle8i-STD-patch/3.delta  ./stage/Components/oracle/install/instcommon/8.1.5.0.0/1/DataFiles/utl.0.0.jar    ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/install/instcommon/8.1.5.0.0/1/DataFiles/utl.0.0.jar
$XDELTA patch -V ./Oracle8i-STD-patch/4.delta  ./stage/Components/oracle/install/instcommon/8.1.5.0.0/1/DataFiles/utl.0.1.jar    ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/install/instcommon/8.1.5.0.0/1/DataFiles/utl.0.1.jar
$XDELTA patch -V ./Oracle8i-STD-patch/5.delta  ./stage/Components/oracle/install/instcommon/8.1.5.0.0/1/DataFiles/utl.0.2.jar    ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/install/instcommon/8.1.5.0.0/1/DataFiles/utl.0.2.jar
$XDELTA patch -V ./Oracle8i-STD-patch/6.delta  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/admin.0.0.jar   ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/admin.0.0.jar
$XDELTA patch -V ./Oracle8i-STD-patch/7.delta  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/bin.0.0.jar     ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/bin.0.0.jar

# different version of these files for different downloadable versions of the standard edition - Oracle is driving me nuts!
# we use the size of the archive to determine if this is the old or the new version
if [ ! -x /usr/bin/du ]; then
    echo "No /usr/bin/du found - next patch will fail. Look at this script to see why."
    echo "(you can still do this manually)"
fi 
if [ ! -x /usr/bin/cut ]; then
    echo "No /usr/bin/cut found - next patch will fail. Look at this script to see why."
    echo "(you can still do this manually)"
fi 

# this patch is only needed for the old version of the standard edition
if [ `du -b ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/class.0.0.jar|cut -f 1` == "195328" ]; then
$XDELTA patch -V ./Oracle8i-STD-patch/8.delta  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/class.0.0.jar   ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/class.0.0.jar
fi

# this patch is different for the old version of the standard edition
if [ `du -b ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/lib.0.1.jar|cut -f 1` == "11600532" ]; then
#old version
$XDELTA patch -V ./Oracle8i-STD-patch/9.delta  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/lib.0.1.jar     ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/lib.0.1.jar
fi
#new version
if [ `du -b ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/lib.0.1.jar|cut -f 1` == "11600858" ]; then
$XDELTA patch -V ./Oracle8i-STD-patch/9n.delta ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/lib.0.1.jar     ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/networking/netclt/8.1.5.0.0/1/DataFiles/lib.0.1.jar
fi

$XDELTA patch -V ./Oracle8i-STD-patch/10.delta ./stage/Components/oracle/p2k/proc/8.1.5.0.0/1/DataFiles/demo.0.0.jar             ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/p2k/proc/8.1.5.0.0/1/DataFiles/demo.0.0.jar
$XDELTA patch -V ./Oracle8i-STD-patch/11.delta ./stage/Components/oracle/p2k/proc/8.1.5.0.0/1/DataFiles/lib.0.0.jar              ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/p2k/proc/8.1.5.0.0/1/DataFiles/lib.0.0.jar
$XDELTA patch -V ./Oracle8i-STD-patch/12.delta ./stage/Components/oracle/rdbms/8.1.5.0.0/1/DataFiles/base.0.1.jar                ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/rdbms/8.1.5.0.0/1/DataFiles/base.0.1.jar
$XDELTA patch -V ./Oracle8i-STD-patch/13.delta ./stage/Components/oracle/utilities/plus/8.1.5.0.0/1/DataFiles/lib.0.0.jar        ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/utilities/plus/8.1.5.0.0/1/DataFiles/lib.0.0.jar
$XDELTA patch -V ./Oracle8i-STD-patch/14.delta ./stage/Components/oracle/utilities/util/8.1.5.0.0/1/DataFiles/lib.0.0.jar        ./tmp.file && \
mv ./tmp.file                                  ./stage/Components/oracle/utilities/util/8.1.5.0.0/1/DataFiles/lib.0.0.jar


echo
echo "No error messages above means everything worked fine."
echo
echo "D O N E."
echo
echo "See README.fixed in your installation directory for a summary of what"
echo "these patches have changed."
echo
cd ./Oracle8i-STD-patch/

echo
echo
echo -n "Shall I start the Oracle Universal Installer right now? [Y/n] "
read answer
echo
echo
 
if [ ${answer:-Y} != "n" -a ${answer:-Y} != "N" ]; then
    cd ..
    ./runInstaller
fi

exit 0

